aboutsummaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorJohn Alhroos <john.ahlroos@itmill.com>2011-08-08 09:41:06 +0000
committerJohn Alhroos <john.ahlroos@itmill.com>2011-08-08 09:41:06 +0000
commit40d3bbeb17b8c4adb2cd4fabccb1b89f2af92f29 (patch)
treefe341ce2784e2bdd91fb3b9800369245c53aff07 /src
parente2fe033c1f9560e5ddeab93cfd154505de93a9e8 (diff)
downloadvaadin-framework-40d3bbeb17b8c4adb2cd4fabccb1b89f2af92f29.tar.gz
vaadin-framework-40d3bbeb17b8c4adb2cd4fabccb1b89f2af92f29.zip
Another regression fix after #6677 #6934
svn changeset:20149/svn branch:6.6
Diffstat (limited to 'src')
-rw-r--r--src/com/vaadin/terminal/gwt/client/ui/VScrollTable.java16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/com/vaadin/terminal/gwt/client/ui/VScrollTable.java b/src/com/vaadin/terminal/gwt/client/ui/VScrollTable.java
index 471d74e2cf..a5411fa0e7 100644
--- a/src/com/vaadin/terminal/gwt/client/ui/VScrollTable.java
+++ b/src/com/vaadin/terminal/gwt/client/ui/VScrollTable.java
@@ -1671,11 +1671,11 @@ public class VScrollTable extends FlowPanel implements Table, ScrollHandler,
}
}
- if (checksum != availW) {
+ if (extraSpace > 0 && checksum != availW) {
/*
* There might be in some cases a rounding error of 1px so if
* there is one then we give the first undefined column 1 more
* pixel
*/
headCells = tHead.iterator();
i = 0;
@@ -5091,11 +5091,11 @@ public class VScrollTable extends FlowPanel implements Table, ScrollHandler,
colIndex++;
}
- if (checksum != totalUndefinedNaturalWidths) {
+ if (extraSpace > 0 && checksum != availW) {
/*
* There might be in some cases a rounding error of 1px so if
* there is one then we give the first undefined column 1 more
* pixel
*/
headCells = tHead.iterator();
colIndex = 0;
@@ -1671,11 +1671,11 @@ public class VScrollTable extends FlowPanel implements Table, ScrollHandler,
/*
- * There might be in some cases a rounding error of 1px so if
- * there is one then we give the first undefined column 1 more
- * pixel
+ * There might be in some cases a rounding error of 1px when
+ * extra space is divided so if there is one then we give the
+ * first undefined column 1 more pixel
*/
headCells = tHead.iterator();
@@ -5091,11 +5091,11 @@ public class VScrollTable extends FlowPanel implements Table, ScrollHandler,
/*
- * There might be in some cases a rounding error of 1px so if
- * there is one then we give the first undefined column 1 more
- * pixel
+ * There might be in some cases a rounding error of 1px when
+ * extra space is divided so if there is one then we give the
+ * first undefined column 1 more pixel
*/
headCells = tHead.iterator();